# midi2mqtt
Listen to MIDI signals and send them to a mqtt broker.

## Installation

It can be installed by pip from pipy or from the git repo location

	# from PyPI
	$ pip install midi2mqtt
	
	# from sources
	$ pip install git+https://github.com/pintman/midi2mqtt

